# coding: utf-8

"""
    Gopad OpenAPI

    API definition for Gopad, Etherpad for markdown with go

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: gopad@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, SecretStr, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class UpdateUserRequest(BaseModel):
    """
    UpdateUserRequest
    """ # noqa: E501
    username: Optional[StrictStr] = None
    password: Optional[SecretStr] = None
    email: Optional[StrictStr] = None
    fullname: Optional[StrictStr] = None
    admin: Optional[StrictBool] = None
    active: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["username", "password", "email", "fullname", "admin", "active"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpdateUserRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if admin (nullable) is None
        # and model_fields_set contains the field
        if self.admin is None and "admin" in self.model_fields_set:
            _dict['admin'] = None

        # set to None if active (nullable) is None
        # and model_fields_set contains the field
        if self.active is None and "active" in self.model_fields_set:
            _dict['active'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpdateUserRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "username": obj.get("username"),
            "password": obj.get("password"),
            "email": obj.get("email"),
            "fullname": obj.get("fullname"),
            "admin": obj.get("admin"),
            "active": obj.get("active")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Gopad OpenAPI

    API definition for Gopad, Etherpad for markdown with go

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: gopad@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.6.0"

# import apis into sdk package
from gopad.api.auth_api import AuthApi
from gopad.api.group_api import GroupApi
from gopad.api.profile_api import ProfileApi
from gopad.api.user_api import UserApi

# import ApiClient
from gopad.api_response import ApiResponse
from gopad.api_client import ApiClient
from gopad.configuration import Configuration
from gopad.exceptions import OpenApiException
from gopad.exceptions import ApiTypeError
from gopad.exceptions import ApiValueError
from gopad.exceptions import ApiKeyError
from gopad.exceptions import ApiAttributeError
from gopad.exceptions import ApiException

# import models into sdk package
from gopad.models.auth_token import AuthToken
from gopad.models.auth_verify import AuthVerify
from gopad.models.create_group_request import CreateGroupRequest
from gopad.models.create_user_request import CreateUserRequest
from gopad.models.delete_group_from_user_request import DeleteGroupFromUserRequest
from gopad.models.delete_user_from_group_request import DeleteUserFromGroupRequest
from gopad.models.group import Group
from gopad.models.list_group_users200_response import ListGroupUsers200Response
from gopad.models.list_groups200_response import ListGroups200Response
from gopad.models.list_providers200_response import ListProviders200Response
from gopad.models.list_user_groups200_response import ListUserGroups200Response
from gopad.models.list_users200_response import ListUsers200Response
from gopad.models.login_auth_request import LoginAuthRequest
from gopad.models.notification import Notification
from gopad.models.permit_group_user_request import PermitGroupUserRequest
from gopad.models.permit_user_group_request import PermitUserGroupRequest
from gopad.models.profile import Profile
from gopad.models.provider import Provider
from gopad.models.update_profile_request import UpdateProfileRequest
from gopad.models.update_user_request import UpdateUserRequest
from gopad.models.user import User
from gopad.models.user_auth import UserAuth
from gopad.models.user_group import UserGroup
from gopad.models.validation import Validation
